#!/bin/sh
# the next line restarts using wish \
exec wishstep8.0 "$0" "$@"

proc ttb_about {} {

	ttb_dialog .about "about Jun's Forest" \
		"Jun's STEP gTar utility\n\nver 1.0\n\nJun Wakaya 1998."\
		jfLogo -32768 0 0 Ok

}

proc ttbTar_truncateList {list} {

	set retList {}

	foreach i $list {
		if {$i == {}} {
			continue
		}

		catch [set retList [concat $retList $i]]
	}

	return $retList
}

proc ttbTar_startCompress {mode fileName} {

	global ttbTarDir

	set aPath [file dirname $fileName]

	set fName [file tail [file rootname [file rootname $fileName]]]
	set oldPwd [pwd]

	switch $mode {
		tgz {
			cd $aPath
			file mkdir $ttbTarDir/$fName
			exec tar zcf $ttbTarDir/$fName/$fName.tar.gz [file tail $fileName]
			cd $oldPwd
		}

		mtgz {
			set fName 
			cd $ttbTarDir [exec date +%s]
			file mkdir $ttbTarDir/$fName
			eval exec tar zcf $ttbTarDir/$fName/$fName.tar.gz $fileName
			cd $oldPwd
		}

		gz  {
			file mkdir $ttbTarDir/$fName
			exec gzip -c $fileName > $ttbTarDir/$fName/$fName.gz
		}
	}

	destroy .opPanel
}

proc ttbTar_startDecompress {mode fileName} {

	global ttbTarDir

	set fName [file tail [file rootname [file rootname $fileName]]]

	switch $mode {
		utar {
			file mkdir $ttbTarDir/$fName
			exec tar xf $fileName -C $ttbTarDir/$fName
		}

		utgz {
			file mkdir $ttbTarDir/$fName
			exec tar zxf $fileName -C $ttbTarDir/$fName
		}

		ugz  {
			file mkdir $ttbTarDir/$fName
			exec gzip -cd $fileName > $ttbTarDir/$fName/$fName
		}

		ulzh  {
			file mkdir $ttbTarDir/$fName
			set pwd [pwd]
			cd $ttbTarDir/$fName/
			exec lha x $fileName
			cd $pwd
		}
	}

	destroy .opPanel
}

proc ttbTar_openWindow {mode dataList} {

	global panelColor stageColor

	toplevel .opPanel
	wm title .opPanel "Jun's STEP compress utility"

	set iList {}

	ttbTar_resize opPanel

	label .opPanel.title -bg $panelColor
	listbox .opPanel.innerList -bg $stageColor
	scrollbar .opPanel.innerListScroll
	button .opPanel.ok -bg $panelColor
	button .opPanel.cancel -bg $panelColor

	pack .opPanel.title
	pack .opPanel.innerListScroll .opPanel.innerList -side left -fill both
	pack .opPanel.ok .opPanel.cancel -fill both -anchor s

	.opPanel.innerList configure -yscrollcommand ".opPanel.innerListScroll set" -width 48
	.opPanel.innerListScroll configure -command ".opPanel.innerList yview"
	.opPanel.cancel configure -text "Cancel" -command "destroy .opPanel"

	switch $mode {
		gz {
			.opPanel.title configure -font {Helvetica 18} -text "Compress:$dataList" -bd 10

			.opPanel.innerList insert end $dataList

			.opPanel.ok configure -text "Start compress" -command "ttbTar_startCompress $mode $dataList" -default active
		}

		tgz {
			.opPanel.title configure -font {Helvetica 18} -text "Compress:$dataList" -bd 10

			.opPanel.innerList insert end $dataList/

			.opPanel.ok configure -text "Start compress" -command "ttbTar_startCompress $mode $dataList" -default active
		}

		utar {
			.opPanel.title configure -font {Helvetica 18} -text "Decompress:$dataList" -bd 10

			set temp [split [exec tar tf $dataList] \n]
			foreach i $temp {
				.opPanel.innerList insert end $i
			}

			.opPanel.ok configure -text "Start decompress" -command "ttbTar_startDecompress $mode $dataList" -default active
		}

		utgz {
			.opPanel.title configure -font {Helvetica 18} -text "Decompress:$dataList" -bd 10

			set temp [split [exec tar ztf $dataList] \n]
			foreach i $temp {
				.opPanel.innerList insert end $i
			}

			.opPanel.ok configure -text "Start decompress" -command "ttbTar_startDecompress $mode $dataList" -default active
		}

		ulzh {
			.opPanel.title configure -font {Helvetica 18} -text "Decompress:$dataList" -bd 10

			set temp [split [exec lha l $dataList] \n]

			set temp2 {}

			foreach i $temp {
				set temp2 "$temp2 [lindex $i 6]"
			}

			set temp2 [ttbTar_truncateList $temp2]

			for {set i 1} {$i<[expr [llength $temp2]-1]} {incr i} {
				.opPanel.innerList insert end [lindex $temp2 $i]
			}

			.opPanel.ok configure -text "Start decompress" -command "ttbTar_startDecompress $mode $dataList" -default active
		}

		ugz {
			.opPanel.title configure -font {Helvetica 18} -text "Decompress:$dataList" -bd 10

			set temp [split [exec gzip -l $dataList] \n]

			for {set i 1} {$i<[llength $temp]} {incr i} {
				catch [set iList [concat $iList [lindex [lindex $temp $i] 3]]]
			}

			set iList [ttbTar_truncateList $iList]

			foreach i $iList {
				.opPanel.innerList insert end $i
			}

			.opPanel.ok configure -text "Start decompress" -command "ttbTar_startDecompress $mode $dataList" -default active
		}

		default {
			destroy .opPanel
		}
	}
}

proc ttbTar_drop {datas} {
	set dataList [join [split $datas \n]]

	if {[llength $dataList]==1} {
		switch [file type $dataList] {
			file {
				if {[file extension $dataList]!=".gz"} {
					set mode gz
				} else {
					if {[file extension [file rootname $dataList]]==".tar"} {
						set mode utgz
					} else {
						set mode ugz
					}
				}

				switch [file extension $dataList] {
					".tgz" {
						set mode utgz
					}

					".taz" {
						set mode utgz
					}

					".Z" {
						if {[file extension [file rootname $dataList]]==".tar"} {
							set mode utgz
						} else {
							set mode ugz
						}
					}

					".tar" {
						set mode utar
					}

					".lzh" {
						set mode ulzh
					}
				}
			}

			directory {
				set mode tgz
			}

			default {
				puts error
			}
		}
	} else {
		set mode mtgz
	}

	ttbTar_openWindow $mode $dataList
}

proc ttbTar_resize {toplevel} {

	switch $toplevel {
		root {
			ttb_resize
		}

		opPanel {
			.opPanel configure -bd 10 -relief flat -width 480 -height 320
		}
	}
}

proc ttbTar_rootCreate {ttblibPath} {
	image create photo WinFrame -file $ttblibPath/icons/system/tile.gif
	image create photo DarkForestImage -file $ttblibPath/icons/app/DarkForest.gif
	image create photo jfLogo -file "$ttblibPath/icons/system/JFLOGO.gif"

	label .base -image WinFrame -bd 0 
	label .base.img -bd 0 -image DarkForestImage -highlightthickness 0

	pack .base -fill both
	pack propagate .base false
	place .base.img -x 8 -y 8 
}

proc ttbTar_bind {} {
	bind . <Drop> "ttbTar_drop %D"
	ttb_bind
}

proc ttb_showPopup {mode x y fname} {
	global ttbsendList ttbbookmarkList filt

	if {[winfo exists .ttb_popup]} {
		destroy .ttb_popup
	}

	menu .ttb_popup -tearoff 0

	switch $mode {
		"top" {
#			.ttb_popup add command -label "about Jun's Forest" -command ttb_about
			.ttb_popup add command -label "exit" -command exit
		}

	}
	tk_popup .ttb_popup $x $y
}

set ttblibPath $env(HOME)/GNUstep/Library/JunsSTEP
set ttblogo $ttblibPath/icons/system/JFLOGO.gif
set stageColor #c0c0c0
set panelColor #c0c0c0
set ttbTarDir $env(HOME)
set ttblogo {}
set appName Forest

source $ttblibPath/functions/ttb_dialog.tcl
source $ttblibPath/functions/ttbinit.tcl

ttbTar_rootCreate $ttblibPath
ttbTar_resize root
ttbTar_bind

